@@ -26,8 +26,10 @@ module Vagrant
             config.customize 'mount.entry', '/sys/fs/selinux sys/fs/selinux none bind,ro 0 0'
           end
 
-          # Make /tmp a tmpfs to prevent init scripts from nuking synced folders mounted in here
-          config.customize 'mount.entry', 'tmpfs tmp tmpfs nodev,nosuid,size=2G 0 0'
+          if config.tmpfs_mount_size && !config.tmpfs_mount_size.empty?
+            # Make /tmp a tmpfs to prevent init scripts from nuking synced folders mounted in here
+            config.customize 'mount.entry', "tmpfs tmp tmpfs nodev,nosuid,size=#{config.tmpfs_mount_size} 0 0"
+          end
 
           env[:ui].info I18n.t("vagrant_lxc.messages.starting")
           env[:machine].provider.driver.start(config.customizations)
