@@ -19,14 +19,20 @@ module Vagrant
               container_name = generate_container_name(env)
           end
 
-          env[:machine].provider.driver.create(
+          backingstore = config.backingstore
+          if backingstore.nil?
+            backingstore = config.privileged ? "best" : "dir"
+          end
+          driver = env[:machine].provider.driver
+          driver.create(
             container_name,
-            config.backingstore,
+            backingstore,
             config.backingstore_options,
             env[:lxc_template_src],
             env[:lxc_template_config],
             env[:lxc_template_opts]
           )
+          driver.update_config_keys
 
           env[:machine].id = container_name
 
