@@ -1,5 +1,8 @@
 require 'tempfile'
 
+require "vagrant-lxc/driver"
+require "vagrant-lxc/sudo_wrapper"
+
 module Vagrant
   module LXC
     module Command
@@ -25,7 +28,7 @@ module Vagrant
           argv = parse_options(opts)
           return unless argv
 
-          wrapper_path = Vagrant::LXC.sudo_wrapper_path
+          wrapper_path = SudoWrapper.dest_path
           wrapper = create_wrapper!
           sudoers = create_sudoers!(options[:user], wrapper_path)
 
@@ -43,12 +46,14 @@ module Vagrant
 
         # This requires vagrant 1.5.2+ https://github.com/mitchellh/vagrant/commit/3371c3716278071680af9b526ba19235c79c64cb
         def create_wrapper!
+          lxc_base_path = Driver.new("").containers_path
           wrapper = Tempfile.new('lxc-wrapper').tap do |file|
             template = Vagrant::Util::TemplateRenderer.new(
               'sudoers.rb',
               :template_root  => Vagrant::LXC.source_root.join('templates').to_s,
               :cmd_paths      => build_cmd_paths_hash,
-              :pipework_regex => "#{ENV['HOME']}/\.vagrant\.d/gems/gems/vagrant-lxc.+/scripts/pipework"
+              :lxc_base_path  => lxc_base_path,
+              :pipework_regex => "#{ENV['HOME']}/\.vagrant\.d/gems/(?:\\d+?\\.\\d+?\\.\\d+?/)?gems/vagrant-lxc.+/scripts/pipework"
             )
             file.puts template.render
           end
@@ -80,9 +85,9 @@ module Vagrant
         def build_cmd_paths_hash
           {}.tap do |hash|
             %w( which cat mkdir cp chown chmod rm tar chown ip ifconfig brctl ).each do |cmd|
-              hash[cmd] = `which #{cmd}`.strip
+              hash[cmd] = `sudo which #{cmd}`.strip
             end
-            hash['lxc_bin'] = Pathname(`which lxc-create`.strip).parent.to_s
+            hash['lxc_bin'] = Pathname(`sudo which lxc-create`.strip).parent.to_s
             hash['ruby'] = Gem.ruby
           end
         end
