@@ -3,6 +3,7 @@ require "vagrant/util/subprocess"
 
 require "vagrant-lxc/errors"
 require "vagrant-lxc/driver/cli"
+require "vagrant-lxc/sudo_wrapper"
 
 require "etc"
 
@@ -16,15 +17,13 @@ module Vagrant
       class ContainerNotFound < StandardError; end
 
       # Default root folder where container configs are stored
-      DEFAULT_CONTAINERS_PATH = '/var/lib/lxc'
-
       attr_reader :container_name,
                   :customizations
 
-      def initialize(container_name, sudo_wrapper, cli = nil)
+      def initialize(container_name, sudo_wrapper = nil, cli = nil, privileged: true)
         @container_name = container_name
-        @sudo_wrapper   = sudo_wrapper
-        @cli            = cli || CLI.new(sudo_wrapper, container_name)
+        @sudo_wrapper   = sudo_wrapper || SudoWrapper.new(privileged: privileged)
+        @cli            = cli || CLI.new(@sudo_wrapper, container_name)
         @logger         = Log4r::Logger.new("vagrant::provider::lxc::driver")
         @customizations = []
       end
@@ -35,7 +34,7 @@ module Vagrant
 
       # Root folder where container configs are stored
       def containers_path
-        @containers_path ||= @cli.support_config_command? ? @cli.config('lxc.lxcpath') : DEFAULT_CONTAINERS_PATH
+        @containers_path ||= @cli.config('lxc.lxcpath')
       end
 
       def all_containers
@@ -46,6 +45,10 @@ module Vagrant
         Pathname.new("#{containers_path}/#{@container_name}")
       end
 
+      def config_path
+        base_path.join('config').to_s
+      end 
+
       def rootfs_path
         config_entry = config_string.match(/^lxc\.rootfs\s+=\s+(.+)$/)[1]
         case config_entry
@@ -73,7 +76,7 @@ module Vagrant
       end
 
       def config_string
-        @sudo_wrapper.run('cat', base_path.join('config').to_s)
+        @sudo_wrapper.run('cat', config_path)
       end
 
       def create(name, backingstore, backingstore_options, template_path, config_file, template_options = {})
@@ -126,6 +129,10 @@ module Vagrant
         @cli.attach(*command)
       end
 
+      def info(*command)
+        @cli.info(*command)
+      end
+
       def configure_private_network(bridge_name, bridge_ip, container_name, address_type, ip)
         @logger.info "Configuring network interface for #{container_name} using #{ip} and bridge #{bridge_name}"
         if ip
@@ -237,6 +244,12 @@ module Vagrant
         write_config(contents)
       end
 
+      def update_config_keys
+        @cli.update_config(config_path)
+      rescue Errors::ExecuteError
+        # not on LXC 2.1+. Doesn't matter, ignore.
+      end
+
       protected
 
       def write_customizations(customizations)
@@ -253,12 +266,21 @@ module Vagrant
       end
 
       def write_config(contents)
-        Tempfile.new('lxc-config').tap do |file|
-          file.chmod 0644
-          file.write contents
-          file.close
-          @sudo_wrapper.run 'cp', '-f', file.path, base_path.join('config').to_s
-          @sudo_wrapper.run 'chown', 'root:root', base_path.join('config').to_s
+        confpath = base_path.join('config').to_s
+        begin
+          File.open(confpath, File::RDWR) do |file|
+            file.write contents
+          end
+        rescue
+          # We don't have permissions to write in the conf file. That's probably because it's a
+          # privileged container. Work around that through sudo_wrapper.
+          Tempfile.new('lxc-config').tap do |file|
+            file.chmod 0644
+            file.write contents
+            file.close
+            @sudo_wrapper.run 'cp', '-f', file.path, confpath
+            @sudo_wrapper.run 'chown', 'root:root', confpath
+          end
         end
       end
     end
